# Generate schema

Before using the `heurist schema` subcommand, review the [instructions on how to configure the command-line interface (CLI)](./index.md#configure-the-cli).

> Documentation is under development.

```console
heurist schema -t OUTPUT_TYPE
```

Specify the format in which you want to read the schema, either `csv` or `json`.

```shell
$ heurist schema -t csv
Downloading schemas ⠋ 0:00:04
Describing record types ━━━━━━━━━━━━ 3/3
```
